Library Reference - Export Tools — Bonsu - The Interactive Phase Retrieval Suite 3.4.6 documentation

# Library Reference - Export Tools

## Array to VTK

Convert an input NumPy array into VTK file format. Uses either the amplitude or phase of the array.

Parameters:

Input file

  User provided path string to the input NumPy file.

Output File

  User provided path string for the output VTK file.

Type

  Use either the amplitude or the phase of the complex `input file` in order to construct a VTK array.

## Memory to Array

Provides a means to save to disk a NumPy array stored in memory. See Array to Memory for furthr details.

Parameters:

Input file

  User provided path string to the input NumPy file.

Output File

  User provided choice of memory keyword.

## Object to VTK

Convert an input NumPy array and it’s corresponding co-ordinates array into VTK file format. Uses either the amplitude or phase of the array.

Parameters:

Input file

  User provided path string to the input NumPy file.

Co-ord’s File

  User provided path string to the corresponding co-ordinates NumPy file. Generating coordinates files is achieved using the Coordinate transformation operation.

Output File

  User provided path string for the output VTK file.

Type

  Use either the amplitude or the phase of the complex `input file` in order to construct a VTK array.